summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorDaniel Silverstone <dsilvers@digital-scurf.org>2016-09-24 12:23:19 +0100
committerDaniel Silverstone <dsilvers@digital-scurf.org>2016-09-24 12:23:19 +0100
commitd6e385ef5b2a4eb1a8dcfe30ac3dae790ca1e9e9 (patch)
tree3bd22b68e051bcc97e9cf0b8c24a5401045221f3 /lib
parent39dad79532b6cb1a4b0d4c12901017fc706e42f5 (diff)
downloadgitano-d6e385ef5b2a4eb1a8dcfe30ac3dae790ca1e9e9.tar.gz
CONFIG: Ensure keyrings aren't unexpectedly copied
Diffstat (limited to 'lib')
-rw-r--r--lib/gitano/config.lua5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/gitano/config.lua b/lib/gitano/config.lua
index 81afc19..de52edd 100644
--- a/lib/gitano/config.lua
+++ b/lib/gitano/config.lua
@@ -389,10 +389,11 @@ local function commit_config_changes(conf, desc, author, committer)
-- and write out a commit.
local newtree = {}
- -- Shallow copy the tree ready for mods, skipping users and groups
+ -- Shallow copy the tree ready for mods, skipping keyrings, users and groups
for k,v in pairs(conf.content) do
if not (k:match("^users/") or
- k:match("^groups/")) then
+ k:match("^groups/") or
+ k:match("^keyrings/")) then
newtree[k] = v
end
end